Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(512)

Unified Diff: chrome/browser/extensions/extension_uninstall_dialog.h

Issue 10453101: Convert most of the rest of chrome to ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extension_uninstall_dialog.h
diff --git a/chrome/browser/extensions/extension_uninstall_dialog.h b/chrome/browser/extensions/extension_uninstall_dialog.h
index 83b4ab19a422d42ab94e193d481245a600725341..6d465c8935b2237ea52fc294c02ce449ec0bbd44 100644
--- a/chrome/browser/extensions/extension_uninstall_dialog.h
+++ b/chrome/browser/extensions/extension_uninstall_dialog.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -7,10 +7,10 @@
#pragma once
#include "base/basictypes.h"
-#include "base/memory/weak_ptr.h"
#include "base/compiler_specific.h"
+#include "base/memory/weak_ptr.h"
#include "chrome/browser/extensions/image_loading_tracker.h"
-#include "third_party/skia/include/core/SkBitmap.h"
+#include "ui/gfx/image/image_skia.h"
class MessageLoop;
class Profile;
@@ -60,11 +60,11 @@ class ExtensionUninstallDialog
const extensions::Extension* extension_;
// The extensions icon.
- SkBitmap icon_;
+ gfx::ImageSkia icon_;
private:
// Sets the icon that will be used in the dialog. If |icon| contains an empty
// bitmap, then we use a default icon instead.
void SetIcon(const gfx::Image& image);
// ImageLoadingTracker::Observer:
« no previous file with comments | « chrome/browser/extensions/extension_install_ui.cc ('k') | chrome/browser/extensions/extension_uninstall_dialog.cc » ('j') | no next file with comments »
@@ -60,11 +60,11 @@ class ExtensionUninstallDialog
private:
// Sets the icon that will be used in the dialog. If |icon| contains an empty
- // bitmap, then we use a default icon instead.
+ // image, then we use a default icon instead.
void SetIcon(const gfx::Image& image);
// ImageLoadingTracker::Observer:

Powered by Google App Engine
This is Rietveld 408576698